
********************************************
* Analyze Phone Sample CO EXP
* March 2015
********************************************

*cd ""

clear
//local data ..\Data\
//local output ..\Output\
set more off
* Analyze Phone sample
use Final_Anon_COExp_AnalysisDataset.dta

*****************************
* End Merge CO voter file info
*****************************

*** FIX DEMO LABEL
 lab var d_agemiss "Age Missing"
 lab var d_gender_male "Gender=Male (1=Yes)"
 lab var d_gender_unknown "Gender=Unknown (1=Yes)"
 lab var d_race_black "Race=Black (1=Yes)"
 lab var d_race_latino "Race=Latino (1=Yes)"
 lab var d_race_other "Race=Other (1=Yes)"

 *** STANDARDIZE VARIABLES LABLES
 lab var d_voted12gen "Voted in 2012 General Election (1=Yes)"
 lab var d_voted10gen "Voted in 2010 General Election (1=Yes)"
 lab var d_voted12prim "Voted in 2012 Primary Election (1=Yes)"
 lab var d_voted10prim "Voted in 2010 Primary Election (1=Yes)"
 
 lab var d_age "Age in Years"
 lab var d_age2 "Age Squared/100"

* SUM STATS FOR RETURNED DATA

** Q1 (q1intro_precall)
 gen intro_precall_received=(q1intro_precall=="1 Target still on line")
 lab var intro_precall_received "Precall Intro Received"
 
 gen intro_precall_receivedCOND=(q1intro_precall=="1 Target still on line") & (treatment~=5 | treatment~=6)
 lab var intro_precall_receivedCOND "Precall Intro Received - Conditional on Precall Treatment"
 
 ** Q2 (q2voting_precall)
 
 gen precall_vote=(q2voting_precall=="1 Yes")
 lab var precall_vote "Plan to Vote"
 
 gen precall_voteCOND=(q2voting_precall=="1 Target still on line") & (treatment~=5 | treatment~=6)
 lab var precall_voteCOND "Plan to Vote - Conditional on Being Asked"
 
 ** Q3 (q3reminder_precall)
 
 gen precall_want_remind=(q3reminder_precall=="1 Yes")
 lab var precall_want_remind "Yes to Reminder Call"
 
 gen precall_want_remindCOND=(q3reminder_precall=="1 Yes") & (treatment==1 | treatment==2)
 lab var precall_want_remindCOND "Yes to Reminder Call - Conditional on Being Asked"
 
 ** Q1 (q1reminder_reminder)
 gen reminder_received=(q1reminder_reminder=="1 Target still on line")
 lab var reminder_received "Reminder Call Received"
 
 gen reminder_receivedCOND=(q1reminder_reminder=="1 Target still on line") & (treatment==1 | treatment==2)
 lab var reminder_receivedCOND "Reminder Call Received - Conditional on Being Asked"
 
 ** Q2 (q2voting_reminder)
 
 gen reminder_voted=(q2voted_reminder=="1 Yes")
 lab var reminder_voted "Voted in 2014"
 
 gen reminder_votedCOND=(q2voted_reminder=="1 Target still on line") & (treatment~=5 | treatment~=6)
 lab var reminder_votedCOND "Voted in 2014 - Conditional on Being Asked"



* Recode treatment variables and Process Returned Data */

/* For our randomization purposes, assign people to 6 cells:
1) Pre-call offer of reminder, call with reminder
2) Pre-call offer of reminder, no reminder
3) Pre call info [no offer], call with reminder
4) Pre call info [no offer], no reminder
5) No Pre call, call with reminder
6) No Pre call, no reminder
at rates of 
1/4
1/4
1/8
1/8
1/8
1/8

*/

label define treatshort 1 "PreOffer + Remind" 2 "PreOffer + No Remind" 3 "PreNoOffer + Remind" 4 "PreNoOffer + No Remind" 5 "No Pre + Remind" 6 "No Pre + No Offer"
label values treatment treatshort

* Table 2
tab treatment

******************************
* Create Treatment Conditions
*****************************

gen t_pre_offer_remind=0
gen t_pre_offer_noremind=0
gen t_pre_nooffer_remind=0
gen t_pre_nooffer_noremind=0
gen t_nopre_remind=0
gen t_nopre_noremind=0

replace t_pre_offer_remind=1 if treatment == 1
replace t_pre_offer_noremind=1 if treatment == 2
replace t_pre_nooffer_remind=1 if treatment == 3
replace t_pre_nooffer_noremind=1 if treatment == 4
replace t_nopre_remind=1 if treatment == 5
replace t_nopre_noremind=1 if treatment == 6

* Label Treatment Variables
label var t_pre_offer_remind "Early GOTV call including reminder call offer followed by a late GOTV call" 
label var t_pre_offer_noremind "Early GOTV call including reminder call offer not followed by a late GOTV call" 
label var t_pre_nooffer_remind "Early GOTV call without a reminder call offer followed by a late GOTV call" 
label var t_pre_nooffer_noremind "Early GOTV call without a reminder call offer not followed by a late GOTV call" 
label var t_nopre_remind "Treat = Late GOTV call only" 
label var t_nopre_noremind "Pure Control" 

gen Zprecalloffer=(treatment==1 | treatment==2)
gen Zprecallnoffer=(treatment==3 | treatment==4)
gen Zreminder=treatment==1 | treatment ==3 | treatment==5
label var Zprecalloffer "Pre Call Offered Reminder"
label var Zprecallnoffer "Pre Call Without Offer"
label var Zreminder "Reminder Call Provided"

*************************************************************
* Code up outcome
*************************************************************
gen outcome_voted2014g=(vf_voted_14_g==1)
label var outcome_voted2014g "Voted in 2014 General Election(1=Yes, 0=No or Missing in VF)"


*************************************************************
* Create variable indicating that person fullfilled treatment
*************************************************************

* Two different definitions of contact according to pre-call
* For comparisons AMONG the set of people who got any pre-call (reminder offer or no reminder offer) we can condition on getting through the first question (q1intro_precal=="1 Target still on line")
gen precall_realized_t1234=q1intro_precal=="1 Target still on line" if (treatment==1 | treatment==2 | treatment==3 | treatment==4)
label var precall_realized_t1234 "Pre Call Contact Achieved"
gen precall_altrealized_t1234=(q1intro_precal=="1 Target still on line" | q1intro_precal=="9 Terminated") if (treatment==1 | treatment==2 | treatment==3 | treatment==4)
label var precall_altrealized_t1234 "Alternative Measure, Pre Call Contact Achieved"

gen tempcallrealized=1 if (precall_realized_t1234==1)
gen tempreminderealized=1 if (reminder_received==1)

* This together is the columns of table 3
tab treatment
version 16: table treatment, c(mean outcome_voted2014g sd outcome_voted2014g )
version 16: table treatment, c(n tempcallrealized mean precall_realized_t1234 n tempreminderealized mean reminder_received)
drop tempcallrealized tempreminderealized


*************************************************************
* Now code up interactions that are conditional on contact measures just defined
*************************************************************

gen wantcall=q3reminder_precall=="1 Yes" if ((treatment==1 | treatment==2) & precall_realized_t1234==1)
label var wantcall "Pre Call Offered Reminder, Person Asked For It"

gen dontwantcall=q3reminder_precall=="2 No" if ((treatment==1 | treatment==2) & precall_realized_t1234==1)
label var dontwantcall "Pre Call Offered Reminder, Person Did Not Want Call"

gen saidwouldvote=q2voting_precal=="1 Yes" if ((treatment==1 | treatment==2 | treatment==3 | treatment==4) & precall_realized_t1234==1)
label var saidwouldvote "During Pre Call, Said Would Vote When Asked"

gen saiduncertain=q2voting_precal=="3 Uncertain" if ((treatment==1 | treatment==2 | treatment==3 | treatment==4) & precall_realized_t1234==1)
label var saiduncertain "During Pre Call, Said Uncertain Would Vote"

gen saidnodisclose=q2voting_precal=="4 Wouldn't Disclose" if ((treatment==1 | treatment==2 | treatment==3 | treatment==4) & precall_realized_t1234==1)
label var saidnodisclose "During Pre Call, Wouldn't Disclose If Would Vote"

gen terminatedbeforeanswer=q2voting_precal=="9 Terminated" if ((treatment==1 | treatment==2 | treatment==3 | treatment==4) & precall_realized_t1234==1)
label var terminatedbeforeanswer "During Pre Call, Call Ended Before Answer Received"

gen unknownifwantcall=(q2voting_precal=="9 Terminated" | q2voting_precal=="3 Uncertain" | q2voting_precal=="4 Wouldn't Disclose") if ((treatment==1 | treatment==2 | treatment==3 | treatment==4) & precall_realized_t1234==1)
label var unknownifwantcall "During Pre Call, Unknown If Wanted Reminder Call"

gen Xt_pre_offer_remind_want=wantcall * t_pre_offer_remind
label var Xt_pre_offer_remind_want "Asked for Reminder, Reminder Provided"

gen Xt_pre_offer_remind_willvote=saidwouldvote*t_pre_offer_remind
label var Xt_pre_offer_remind_willvote "Offered Reminders, Said Would Vote, Reminder Provided"

gen Xt_pre_nooffer_remind_willvote=saidwouldvote*t_pre_nooffer_remind
label var Xt_pre_nooffer_remind_willvote "Pre Call without reminder, Said Would Vote, Reminder Provided"

gen Xt_pre_offer_remind_uncertain=saiduncertain*t_pre_offer_remind
label var Xt_pre_offer_remind_uncertain "Offered Reminders, Said Uncertain Would Vote, Reminder Provided"

gen Xt_pre_offer_remind_terminated=terminatedbeforeanswer*t_pre_offer_remind
label var Xt_pre_offer_remind_terminated "Offered Reminders, Call Ended before Answer Received, Reminder Provided"

gen Xt_pre_nooffer_remind_uncertain=saiduncertain*t_pre_nooffer_remind
label var Xt_pre_nooffer_remind_uncertain "Pre Call Without Reminder, Said Uncertain Would Vote, Reminder Provided"

gen Xt_pre_nooffer_remind_terminated=terminatedbeforeanswer*t_pre_nooffer_remind
label var Xt_pre_nooffer_remind_terminated "Pre Call Without Reminder, Call Ended Before Answer Received, Reminder Provided"

gen Xt_pre_offer_remind_unknown=terminatedbeforeanswer*t_pre_nooffer_remind
label var Xt_pre_offer_remind_unknown "Pre Call Without Reminder, Call Ended Before Answer Received, Reminder Provided"




*****************************************************************************
* From this point on, I include the models that will be reported in the paper. 
* These may be duplicated in the above analyses
*****************************************************************************'

* Causal Quantities of Interest Section *

* First redefine variables for regression

gen anypre=treatment>=1 & treatment<=4

gen anyreminder=treatment==1 | treatment==3 | treatment==5
lab var anyreminder "Attempted Late GOTV Call"

gen noreminder=treatment==2 | treatment==4 | treatment==6
lab var noreminder "No Late GOTV Call Attempted"

** TABLE 4 **

*(1) Among people who got some sort of pre call, what is effect of giving reminder or not (Treatment groups 1-4)
* Reference group: 

regress outcome_voted2014g anyreminder d_* if anypre==1
sum outcome_voted2014g if e(sample) & anyreminder==0
local ref_grp_mean= r(mean)
//outreg2 using "`output'ColoradoReminderCalls_Table1.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Assigned to Receive Early GOTV Call") replace
outreg2 using "Table4_PanelA.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Assigned to Receive Early GOTV Call") replace


*(3) Among people who got some sort of pre call and were successfully contacted, what is effect of giving reminder or not

regress outcome_voted2014g anyreminder d_* if precall_realized_t1234==1
sum outcome_voted2014g if e(sample) & anyreminder==0
local ref_grp_mean= r(mean)
//outreg2 using "`output'ColoradoReminderCalls_Table1.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Assigned to and Contacted in Early GOTV Call") append
outreg2 using "Table4_PanelA.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Assigned to and Contacted in Early GOTV Call") append

** TABLE 5 **

*(4) Among people who were offered a reminder, what is the effect of giving it? (We could also use the anyreminder variable. It is the same) Do we want to run this analysis on those not reached. It's -.2 ITT. I think not. 

regress outcome_voted2014g anyreminder d_* if precall_realized_t1234==1 & (treatment==1 | treatment==2)
sum outcome_voted2014g if e(sample) & t_pre_offer_remind==0 & precall_realized_t1234==1 & (treatment==1 | treatment==2)
local ref_grp_mean= r(mean)
//outreg2 using "`output'ColoradoReminderCalls_Table2.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Offered Reminder") replace
outreg2 using "Table5_PanelA.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Offered Reminder") replace

* (5) Is effect any different based on whether people wanted the call

regress outcome_voted2014g t_pre_offer_remind d_*  if precall_realized_t1234==1 & (treatment==1 | treatment==2) & wantcall ==1
sum outcome_voted2014g if e(sample) &  precall_realized_t1234==1 & t_pre_offer_remind==0 &(treatment==1 | treatment==2) & wantcall ==1
local ref_grp_mean= r(mean)
//outreg2 using "`output'ColoradoReminderCalls_Table2.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Offered and Wanted Reminder") append
outreg2 using "Table5_PanelA.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Offered and Wanted Reminder") append

* (6) Compare those offered but not delivered to those not offered and not delivered
regress outcome_voted2014g t_pre_offer_noremind d_* if precall_realized_t1234==1 & (treatment==2 | treatment==4)
sum outcome_voted2014g if e(sample) & t_pre_nooffer_noremind==1 & precall_realized_t1234==1 & (treatment==2 | treatment==4)
local ref_grp_mean= r(mean)
//outreg2 using "`output'ColoradoReminderCalls_Table2.out", aster(se) dec(3) bracket label  adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Not Assigned Late GOTV Call Attempt") append
outreg2 using "Table5_PanelA.out", aster(se) dec(3) bracket label  adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Not Assigned Late GOTV Call Attempt") append

* (8) * Among people who were not offered a reminder, what is the effect of giving it?
regress outcome_voted2014g t_pre_nooffer_remind d_* if precall_realized_t1234==1 & (treatment==3 | treatment==4)
sum outcome_voted2014g if e(sample) & t_pre_nooffer_noremind==1 & precall_realized_t1234==1 & (treatment==3 | treatment==4)
local ref_grp_mean= r(mean)
//outreg2 using "`output'ColoradoReminderCalls_Table2.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Not Offered Reminder in Early Call") append
outreg2 using "Table5_PanelA.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Not Offered Reminder in Early Call") append



* Heterogenous Treatment Effects. Interaction Models (Table A1 in Appendix)

gen contact_want=(precall_realized_t1234==1) & (q3reminder_precall=="1 Yes")
label var contact_want "Subject Wanted Reminder Call"

gen contact_dontwant=(precall_realized_t1234==1) & (q3reminder_precall=="2 No")
label var contact_dontwant "Subject Didn't Want Reminder Call"

gen contact_unknown=(precall_realized_t1234==1) & (q3reminder_precall=="3 Uncertain" | q3reminder_precall=="4 Wouldn't disclose" | q3reminder_precall=="9 Terminated")
label var contact_unknown "Subject Uncertain/Wouldn't Disclose/Terminated Call"

gen remind_contact_want = t_pre_offer_remind*contact_want
label var remind_contact_want "Interaction: ContactWant*ReminderCall"

gen remind_contact_dontwant = t_pre_offer_remind*contact_dontwant
label var remind_contact_dontwant "Interaction: ContactDontWant*ReminderCall"

gen remind_contact_unknown = t_pre_offer_remind*contact_unknown
label var remind_contact_unknown "Interaction: ContactUnknown*ReminderCall"



regress outcome_voted2014g t_pre_offer_remind contact_want contact_dontwant contact_unknown remind_contact_want remind_contact_dontwant remind_contact_unknown d_* if (treatment==1 | treatment==2)
lincom remind_contact_want-remind_contact_dontwant
local tstat=r(estimate)/r(se)
local pval = tprob(r(df), abs(`tstat'))
lincom remind_contact_dontwant-remind_contact_unknown
local tstat2=r(estimate)/r(se)
local pval2 = tprob(r(df), abs(`tstat2'))
lincom remind_contact_want-remind_contact_unknown
local tstat3=r(estimate)/r(se)
local pval3 = tprob(r(df), abs(`tstat3'))
outreg2 using "TableA1.out", aster(se) dec(3) bracket label adjr2 addstat("B7=B8 P-Value", `pval', "B8=B9 P-Value", `pval2', "B7=B9 P-Value", `pval3') ctitle("Hetereogenous Treatment Effects") replace


** TABLE 6 **

gen will_vote=(precall_realized_t1234==1) & (q2voting_precall=="1 Yes")
label var will_vote "Subject Said Would Vote"

gen willnot_vote=(precall_realized_t1234==1) & (q2voting_precall=="2 No")
label var willnot_vote "Subject Said Would NOT Vote"

gen vote_unknown=(precall_realized_t1234==1) & (q2voting_precall=="3 Uncertain" | q2voting_precall=="4 Wouldn't Disclose" | q2voting_precall=="9 Terminated")
label var vote_unknown "Subject Uncertain/Wouldn't Disclose/Call Terminated"

gen offerremind_will_vote = t_pre_offer_remind*will_vote
label var offerremind_will_vote "Interaction: WillVote*OfferReminderCall"

gen noofferremind_will_vote = t_pre_nooffer_remind*will_vote
label var noofferremind_will_vote "Interaction: WillVote*NoOfferReminderCall"

gen offerremind_vote_unknown = t_pre_offer_remind*vote_unknown
label var offerremind_vote_unknown "Interaction: VoteUnknown*OfferReminderCall"

gen noofferremind_vote_unknown = t_pre_nooffer_remind*vote_unknown
label var noofferremind_vote_unknown "Interaction: VoteUnknown*NoOfferReminderCall"


* Among those who intend to vote,

* Among people who were offered a reminder, what is the effect of giving it? Subsetting on yes voters
regress outcome_voted2014g anyreminder d_* if precall_realized_t1234==1 & q2voting_precall=="1 Yes" & (treatment==1 | treatment==2)
sum outcome_voted2014g if t_pre_offer_remind==0 & precall_realized_t1234==1 & q2voting_precall=="2 No" & (treatment==1 | treatment==2 ) 
local ref_grp_mean= r(mean)
//outreg2 using "`output'ColoradoReminderCalls_Table4.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder AND Said Would Vote") replace
outreg2 using "Table6_PanelA.out", aster(se) dec(3) bracket label adjr2 addstat(Reference Group Mean, `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder AND Said Would Vote") replace

* Among people who were offered a reminder, what is the effect of giving it? Interaction with said would vote
regress outcome_voted2014g anyreminder will_vote vote_unknown offerremind_will_vote offerremind_vote_unknown d_* if precall_realized_t1234==1 & (treatment==1 | treatment==2)
sum outcome_voted2014g if  t_pre_offer_remind==0 & precall_realized_t1234==1 & q2voting_precall=="2 No" & (treatment==1 | treatment==2 ) 
local ref_grp_mean= r(mean)
lincom offerremind_will_vote-offerremind_vote_unknown
local tstat=r(estimate)/r(se)
local pval = tprob(r(df), abs(`tstat'))
//outreg2 using "`output'ColoradoReminderCalls_Table4.out", aster(se) dec(3) bracket label adjr2 addstat("Ho:ß(AssignmentXWillVote)=ß(AssignmentXVoteUnknown) ", `pval', "Reference Group Mean", `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder - IntendtoVote Interaction") append
outreg2 using "Table6_PanelA.out", aster(se) dec(3) bracket label adjr2 addstat("Ho:ß(AssignmentXWillVote)=ß(AssignmentXVoteUnknown) ", `pval', "Reference Group Mean", `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder - IntendtoVote Interaction") append

* Among those who intend to vote,

* Among people who were not offered a reminder, what is the effect of giving it? Interaction with said would vote
regress outcome_voted2014g anyreminder will_vote vote_unknown noofferremind_will_vote noofferremind_vote_unknown  d_* if precall_realized_t1234==1 & (treatment==3 | treatment==4)
sum outcome_voted2014g if t_pre_nooffer_remind==0 & precall_realized_t1234==1 & q2voting_precall=="2 No" & (treatment==3 | treatment==4 ) 
local ref_grp_mean= r(mean)
lincom noofferremind_will_vote-noofferremind_vote_unknown
local tstat=r(estimate)/r(se)
local pval = tprob(r(df), abs(`tstat'))
//outreg2 using "`output'ColoradoReminderCalls_Table4.out", aster(se) dec(3) bracket label adjr2 addstat("Ho:ß(AssignmentXWillVote)=ß(AssignmentXVoteUnknown) ", `pval', "Reference Group Mean", `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those NOT Offered Reminder - IntendtoVote Interaction") append
outreg2 using "Table6_PanelA.out", aster(se) dec(3) bracket label adjr2 addstat("Ho:ß(AssignmentXWillVote)=ß(AssignmentXVoteUnknown) ", `pval', "Reference Group Mean", `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those NOT Offered Reminder - IntendtoVote Interaction") append


***************************
** UNADJUSTED FOR APPENDIX (Panel Bs)
**************************

** TABLE 4 ** 

*(1) Among people who got some sort of pre call, what is effect of giving reminder or not (Treatment groups 1-4)
* Reference group: 

regress outcome_voted2014g anyreminder if anypre==1
sum outcome_voted2014g if e(sample) & anyreminder==0
local ref_grp_mean= r(mean)
outreg2 using "Table4_PanelB.out", aster(se) dec(3) bracket label addstat(Reference Group Mean, `ref_grp_mean') ctitle("Assigned To Receive Early GOTV Call") replace

*(3) Among people who got some sort of pre call and were successfully contacted, what is effect of giving reminder or not

regress outcome_voted2014g anyreminder if precall_realized_t1234==1
sum outcome_voted2014g if e(sample) & anyreminder==0
local ref_grp_mean= r(mean)
outreg2 using "Table4_PanelB.out", aster(se) dec(3) bracket label addstat(Reference Group Mean, `ref_grp_mean') ctitle("Assigned to and Contacted in Early GOTV Call") append

** TABLE 5 **

* Among people who were offered a reminder, what is the effect of giving it? (We could also use the anyreminder variable. It is the same) Do we want to run this analysis on those not reached. It's -.2 ITT. I think not. 

regress outcome_voted2014g anyreminder if precall_realized_t1234==1 & (treatment==1 | treatment==2)
sum outcome_voted2014g if e(sample) & t_pre_offer_remind==0 & precall_realized_t1234==1 & (treatment==1 | treatment==2)
local ref_grp_mean= r(mean)
outreg2 using "Table5_PanelB.out", aster(se) dec(3) bracket label addstat(Reference Group Mean, `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder") replace

* Is effect any different based on whether people wanted the call

regress outcome_voted2014g t_pre_offer_remind if precall_realized_t1234==1 & (treatment==1 | treatment==2) & wantcall ==1
sum outcome_voted2014g if e(sample) &  precall_realized_t1234==1 & t_pre_offer_remind==0 &(treatment==1 | treatment==2) & wantcall ==1
local ref_grp_mean= r(mean)
outreg2 using "Table5_PanelB.out", aster(se) dec(3) bracket label addstat(Reference Group Mean, `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder AND Want Reminder") append

* Compare those offered but not delivered to those not offered and not delivered
regress outcome_voted2014g t_pre_offer_noremind if precall_realized_t1234==1 & (treatment==2 | treatment==4)
sum outcome_voted2014g if e(sample) & t_pre_nooffer_noremind==1 & precall_realized_t1234==1 & (treatment==2 | treatment==4)
local ref_grp_mean= r(mean)
outreg2 using "Table5_PanelB.out", aster(se) dec(3) bracket label addstat(Reference Group Mean, `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those NOT Given Reminder") append


* Among people who were not offered a reminder, what is the effect of giving it?
regress outcome_voted2014g t_pre_nooffer_remind if precall_realized_t1234==1 & (treatment==3 | treatment==4)
sum outcome_voted2014g if e(sample) & t_pre_nooffer_noremind==1 & precall_realized_t1234==1 & (treatment==3 | treatment==4)
local ref_grp_mean= r(mean)
outreg2 using "Table5_PanelB.out", aster(se) dec(3) bracket label addstat(Reference Group Mean, `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those NOT Offered Reminder") append



* (9) Heterogenous Treatment Effects. Interaction Models

regress outcome_voted2014g t_pre_offer_remind contact_want contact_dontwant contact_unknown remind_contact_want remind_contact_dontwant remind_contact_unknown if (treatment==1 | treatment==2)
lincom remind_contact_want-remind_contact_dontwant
local tstat=r(estimate)/r(se)
local pval = tprob(r(df), abs(`tstat'))
lincom remind_contact_dontwant-remind_contact_unknown
local tstat2=r(estimate)/r(se)
local pval2 = tprob(r(df), abs(`tstat2'))
lincom remind_contact_want-remind_contact_unknown
local tstat3=r(estimate)/r(se)
local pval3 = tprob(r(df), abs(`tstat3'))
outreg2 using "TableA3.out", aster(se) dec(3) bracket label adjr2 addstat("B7=B8 P-Value", `pval', "B8=B9 P-Value", `pval2', "B7=B9 P-Value", `pval3') ctitle("Hetereogenous Treatment Effects") replace


** TABLE 6 **

* Among those who intend to vote,

* Among people who were offered a reminder, what is the effect of giving it? Subsetting on yes voters
regress outcome_voted2014g anyreminder if precall_realized_t1234==1 & q2voting_precall=="1 Yes" & (treatment==1 | treatment==2)
sum outcome_voted2014g if t_pre_offer_remind==0 & precall_realized_t1234==1 & q2voting_precall=="2 No" & (treatment==1 | treatment==2 ) 
local ref_grp_mean= r(mean)
//outreg2 using "`output'ColoradoReminderCalls_AppendixTable4.out", aster(se) dec(3) bracket label addstat(Reference Group Mean, `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder AND Said Would Vote") replace
outreg2 using "Table6_PanelB.out", aster(se) dec(3) bracket label addstat(Reference Group Mean, `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder AND Said Would Vote") replace


* Among people who were offered a reminder, what is the effect of giving it? Interaction with said would vote
regress outcome_voted2014g anyreminder will_vote vote_unknown offerremind_will_vote offerremind_vote_unknown if precall_realized_t1234==1 & (treatment==1 | treatment==2)
sum outcome_voted2014g if  t_pre_offer_remind==0 & precall_realized_t1234==1 & q2voting_precall=="2 No" & (treatment==1 | treatment==2 ) 
local ref_grp_mean= r(mean)
lincom offerremind_will_vote-offerremind_vote_unknown
local tstat=r(estimate)/r(se)
local pval = tprob(r(df), abs(`tstat'))
//outreg2 using "`output'ColoradoReminderCalls_AppendixTable4.out", aster(se) dec(3) bracket label adjr2 addstat("Ho:ß(AssignedReminderXWillVote)=ß(AssignedReminderXVoteUnknown) ", `pval', "Reference Group Mean", `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder - IntendtoVote Interaction") append
outreg2 using "Table6_PanelB.out", aster(se) dec(3) bracket label adjr2 addstat("Ho:ß(AssignedReminderXWillVote)=ß(AssignedReminderXVoteUnknown) ", `pval', "Reference Group Mean", `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those Offered Reminder - IntendtoVote Interaction") append

* Among those who intend to vote,

* Among people who were not offered a reminder, what is the effect of giving it? Interaction with said would vote
regress outcome_voted2014g anyreminder will_vote vote_unknown noofferremind_will_vote noofferremind_vote_unknown if precall_realized_t1234==1 & (treatment==3 | treatment==4)
sum outcome_voted2014g if t_pre_nooffer_remind==0 & precall_realized_t1234==1 & q2voting_precall=="2 No" & (treatment==3 | treatment==4 ) 
local ref_grp_mean= r(mean)
lincom noofferremind_will_vote-noofferremind_vote_unknown
local tstat=r(estimate)/r(se)
local pval = tprob(r(df), abs(`tstat'))
//outreg2 using "`output'ColoradoReminderCalls_AppendixTable4.out", aster(se) dec(3) bracket label adjr2 addstat("Ho:ß(AssignedReminderXWillVote)=ß(AssignedReminderXVoteUnknown) ", `pval', "Reference Group Mean", `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those NOT Offered Reminder - IntendtoVote Interaction") append
outreg2 using "Table6_PanelB.out", aster(se) dec(3) bracket label adjr2 addstat("Ho:ß(AssignedReminderXWillVote)=ß(AssignedReminderXVoteUnknown) ", `pval', "Reference Group Mean", `ref_grp_mean') ctitle("Conditional on Pre Call Contact Among Those NOT Offered Reminder - IntendtoVote Interaction") append

** BALANCE TABLE A2 **

*** a. All pre-treatment covariates by treatment assignment for initial randomization (6-arm) 
	forvalues ctr=1(1)6 {

		if(`ctr'==1){
			local clabel = "PreOffer + Remind"
		}
		else if (`ctr'==2){
			local clabel = "PreOffer + No Remind"
		}
		else if (`ctr'==3){
			local clabel = "PreNoOffer + Remind"
		}
		else if (`ctr'==4){
			local clabel = "PreNoOffer + No Remind"
		}
		else if (`ctr'==5){
			local clabel = "NoPre + Remind "
		}
		else if (`ctr'==6){
			local clabel = "NoPre + No Remind"
		}

		if `ctr'==1 {
		 outsum d_* using TableA2_PanelA.out if treatment==`ctr', bracket ctitle("`clabel'")  replace
		}
		else {
		 outsum d_* using TableA2_PanelA.out if treatment==`ctr', bracket ctitle("`clabel'")  append  
		}
	}

*** b. % Contacted in pre-call by assignment to a reminder call, among those assigned to any pre-call
	forvalues ctr=1(1)6 {

		if(`ctr'==1){
			local clabel = "PreOffer + Remind"
		}
		else if (`ctr'==2){
			local clabel = "PreOffer + No Remind"
		}
		else if (`ctr'==3){
			local clabel = "PreNoOffer + Remind"
		}
		else if (`ctr'==4){
			local clabel = "PreNoOffer + No Remind"
		}
		else if (`ctr'==5){
			local clabel = "NoPre + Remind "
		}
		else if (`ctr'==6){
			local clabel = "NoPre + No Remind"
		}

		if `ctr'==1 {
		 outsum precall_realized_t1234 using TableA2_PanelB.out if treatment==`ctr', bracket ctitle("`clabel'") replace
		}
		else {
		 outsum  precall_realized_t1234 using TableA2_PanelB.out if treatment==`ctr',  bracket ctitle("`clabel'") append
		}

	}


*** c. % Contacted and Want Reminder Call, % Contacted and Dont Want Reminder Call, %Contacted and Reminder Call Preference Unknown, and % Not Contacted by assignment to a reminder call, among those assigned to a pre-call w/ a reminder call offer
	forvalues ctr=1(1)6 {

		if(`ctr'==1){
			local clabel = "PreOffer + Remind"
		}
		else if (`ctr'==2){
			local clabel = "PreOffer + No Remind"
		}
		else if (`ctr'==3){
			local clabel = "PreNoOffer + Remind"
		}
		else if (`ctr'==4){
			local clabel = "PreNoOffer + No Remind"
		}
		else if (`ctr'==5){
			local clabel = "NoPre + Remind "
		}
		else if (`ctr'==6){
			local clabel = "NoPre + No Remind"

			}
		if `ctr'==1 {
		 outsum contact_want contact_dontwant contact_unknown using TableA2_PanelC.out if treatment==`ctr', bracket ctitle("`clabel'") replace
		}
		else {
		 outsum contact_want contact_dontwant contact_unknown using TableA2_PanelC.out if treatment==`ctr', bracket ctitle("`clabel'") append
		}

	}




*** d. % Contacted and Stated Will Vote, % Contacted and Stated Wont Vote, % Contacted and Vote Intention Unknown, and % Not Contacted by assignment to a reminder call, among those assigned to a pre-call
	forvalues ctr=1(1)6 {

		if(`ctr'==1){
			local clabel = "PreOffer + Remind"
		}
		else if (`ctr'==2){
			local clabel = "PreOffer + No Remind"
		}
		else if (`ctr'==3){
			local clabel = "PreNoOffer + Remind"
		}
		else if (`ctr'==4){
			local clabel = "PreNoOffer + No Remind"
		}
		else if (`ctr'==5){
			local clabel = "NoPre + Remind "
		}
		else if (`ctr'==6){
			local clabel = "NoPre + No Remind"
			
			}

		if `ctr'==1 {
		 outsum will_vote willnot_vote vote_unknown using TableA2_PanelD.out if treatment==`ctr', bracket ctitle("`clabel'") replace
		}
		else {
		 outsum will_vote willnot_vote vote_unknown using TableA2_PanelD.out if treatment==`ctr', bracket ctitle("`clabel'") append
		}

	}
